# txdps.py
Tired of refreshing website for a TX DPS Appointment? Now do it programmatically!

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

## Features
* Check existing appointment
* Find available time slots at nearby DPS offices
* Get earlist time slot nearby
* Book an appointment programmatically

## Table of Contents

## Getting Started